function [dctf,Lm]=contrast_2(s,Ncuan,norm)

% CONTRAST normaliza las amplitudes de una DCT local de resolucion N 
% Podemos elegir entre diferentes normalizaciones:
%
%   Norm = 1 ......... Normalizamos mediante la luminancia media del subbloque considerado.
%
%   Norm = 2 ......... Normalizamos mediante la luminancia media del subbloque considerado y
%                      de los subbloques del entorno. Hay que introducir como parametro que
%                      numero de subbloques queremos tomar de entorno.
%
%   Norm = 3 ......... Normalizamos mediante la luminancia media de toda la imagen.
%
%   Norm = 4 ......... Normalizamos mediante el valor (de luminancia) introducido como parametro
%                      (valor*l^2), donde l es el lado del subbloque de las DCTs locales. 
% 
% 
% NOTA: Al hablar de luminancia nos referimos a la magnitud en la que este expresada la imagen
%       de entrada. Salvo calibracion, la imagen de entrada suele expresarse en 'niveles de gris',
%       no estrictamente en luminancia.
%
% DE MOMENTO SOLO NORMALIZACIONES 1 y 3 (que incluye la 3 y la 4 porque como parametro hay
%                                        que pasarle el valor medio de la imagen -u otro!-)
% 
% 
% USO: [dctf,Lm]=contrast(dcti,Ncuan,[Norm parametro]);
%  
   
   par=norm(2);
   norm=norm(1);
   tam=size(s);
   tam=tam(1);
   lados=[tam tam];

   dctf=zeros(tam,tam);

   lcuan=tam/(2^Ncuan);
   posai=[tam tam]/2-round(tam/2);
   posbd=[tam tam]/2+round(tam/2);
   coorcuanai=floor([(posai(1)-1)/lcuan+1 (posai(2)-1)/lcuan+1]);
   coorcuanbd=floor([(posbd(1)-1)/lcuan+1 (posbd(2)-1)/lcuan+1]);
   if coorcuanai(1)<1
        coorcuanai(1)=1;
   end 
   if coorcuanai(2)<1
        coorcuanai(2)=1;
   end 
   if coorcuanbd(1)>(2^Ncuan)
        coorcuanbd(1)=2^Ncuan;
   end     
   if coorcuanai(2)>(2^Ncuan)
        coorcuanbd(2)=2^Ncuan;
   end 
      
   
   for ii=coorcuanai(1):coorcuanbd(1)
       for jj=coorcuanai(2):coorcuanbd(2)
    
           iii=(ii-1)*lcuan+ceil(lcuan/2);
           jjj=(jj-1)*lcuan+ceil(lcuan/2); 
           blo=sacasub(s,[iii jjj],[lcuan lcuan],0);

           cub=blo;

           fla=0;
           if cub(1,1)==0
              fla=1;
              cub(1,1)=10;
           end
              if norm==1
                 cub(2:lcuan,1)=2*cub(2:lcuan,1)/cub(1,1);
                 cub(1,2:lcuan)=2*cub(1,2:lcuan)/cub(1,1);
                 cub(2:lcuan,2:lcuan)=4*cub(2:lcuan,2:lcuan)/cub(1,1);
%                cub(1,1)=cub(1,1)/(4*lcuan^2);
                 Lm(ii,jj)=cub(1,1)/lcuan;
              elseif norm==2
                 Lmed=[];
                 for k=-par:par
                     for l=-par:par
                         cubil=sacasub(s,[iii+k jjj+l],[lcuan lcuan],0);
                         med=mean(mean(cubil));
                         if med>0
                            Lmed=[Lmed med];
                         end 
                     end
                 end 
                 Lmedia=4*mean(Lmed)*lcuan^2;
                 cub(2:lcuan,1)=2*cub(2:lcuan,1)/Lmedia;
                 cub(1,2:lcuan)=2*cub(1,2:lcuan)/Lmedia;
                 cub(2:lcuan,2:lcuan)=4*cub(2:lcuan,2:lcuan)/Lmedia;
%                cub(1,1)=cub(1,1)/(4*lcuan^2);
              elseif norm==3
                 Lmedia=par;
                 cub11=Lmedia*lcuan;
                 cub(2:lcuan,1)=2*cub(2:lcuan,1)/cub11;
                 cub(1,2:lcuan)=2*cub(1,2:lcuan)/cub11;
                 cub(2:lcuan,2:lcuan)=4*cub(2:lcuan,2:lcuan)/cub11;
                 Lm(ii,jj)=cub(1,1)/lcuan;
%                cub(1,1)=cub(1,1)/(4*lcuan^2);
              elseif norm==4  
                 cub(2:lcuan,1)=2*cub(2:lcuan,1)/(4*par*lcuan^2);
                 cub(1,2:lcuan)=2*cub(1,2:lcuan)/(4*par*lcuan^2);
                 cub(2:lcuan,2:lcuan)=4*cub(2:lcuan,2:lcuan)/(4*par*lcuan^2);
%                cub(1,1)=cub(1,1)/(4*lcuan^2);
              else
                 cub(2:lcuan,1)=cub(2:lcuan,1)/2;
                 cub(1,2:lcuan)=cub(1,2:lcuan)/2;               
              end

 
%              if norm==1
%                 dctc(2:lcuan,1)=dctc(2:lcuan,1)*cubs(1,1)/2;
%                 dctc(1,2:lcuan)=dctc(1,2:lcuan)*cubs(1,1)/2;
%                 dctc(2:lcuan,2:lcuan)=dctc(2:lcuan,2:lcuan)*cubs(1,1)/4;
%                 dctc(1,1)=cub(1,1);
%              elseif norm==2
%                 dctc(2:lcuan,1)=dctc(2:lcuan,1)*Lmedia/2;
%                 dctc(1,2:lcuan)=dctc(1,2:lcuan)*Lmedia/2;
%                 dctc(2:lcuan,2:lcuan)=dctc(2:lcuan,2:lcuan)*Lmedia/4;
%                 dctc(1,1)=cub(1,1);
%              elseif norm==3
%                 dctc(2:lcuan,1)=dctc(2:lcuan,1)*Lmedia/2;
%                 dctc(1,2:lcuan)=dctc(1,2:lcuan)*Lmedia/2;
%                 dctc(2:lcuan,2:lcuan)=dctc(2:lcuan,2:lcuan)*Lmedia/4;
%                 dctc(1,1)=cub(1,1);
%              elseif norm==4
%                 dctc(2:lcuan,1)=dctc(2:lcuan,1)*(4*par*lcuan^2)/2;
%                 dctc(1,2:lcuan)=dctc(1,2:lcuan)*(4*par*lcuan^2)/2;
%                 dctc(2:lcuan,2:lcuan)=dctc(2:lcuan,2:lcuan)*(4*par*lcuan^2)/4;
%                 dctc(1,1)=cub(1,1);
%              else
%                 dctc(2:lcuan,1)=2*dctc(2:lcuan,1);
%                 dctc(1,2:lcuan)=2*dctc(1,2:lcuan);
%              end

%           if fla==1
%              dctc(1,1)=0;
%              cod(1,1)=0;
%           end

           dctf=metesub(dctf,[iii jjj],cub);

       end 
   end
