function [RMSE,SSIM,MPEl,MPEnl,MPEnlJMLR] = calculo_distorsiones(Im,ImR,pesos)

% Calcula el RMSE, el SSIM, el MPE lineal, el MPE no lineal y el MPE no
% lineal JMLR para una imagen distorsionada.
%
% Im    -> Imagen original
% ImR   -> Imagen distorsionada
% pesos -> Para imagenes RGB sera un vector fila con los valores que
%          pesaran las distorsiones para cada una de las capas YUV
%
% Para imagenes acromaticas, el calculo de los MPE's no necesitara de una
% transformacion YUV previa (obvio).

if(nargin < 3)
    pesos = 1;
end

% Pasamos las imagenes a double
Im = double(Im);
ImR = double(ImR);

% Tercera dimension de la imagen
N = size(Im,3);


% Calculo de distorsiones
% RMSEn = zeros(N,1);
SSIMn = zeros(N,1);
MPEln = zeros(N,1);
MPEnln = zeros(N,1);
MPEnlJMLRn = zeros(N,1);

% Distorsiones
% RMSE = 0;
SSIM = 0;
MPEl = 0;
MPEnl = 0;
MPEnlJMLR = 0;

if(N == 3)
    
    % Pasamos las imagenes al dominio YUV
    ImYUV = my_rgb2yuv(double(Im));
    ImRYUV = my_rgb2yuv(double(ImR));

end

% Para cada capa...
for capa = 1:N

%     % RMSE
%     [RMSEn(capa),SNRi] = emse2(double(Im(:,:,capa)),ImR(:,:,capa));

    % SSIM
    SSIMn(capa) = ssim_index(double(Im(:,:,capa)),ImR(:,:,capa));

    if(N == 3)
        
        % MPE lineal
        [MSE,MPEln(capa),dx0,MPEx0,MPEoo0,MPEexpesp0] = disdis_lineal(double(ImYUV(:,:,capa)),ImRYUV(:,:,capa),2,[3 mean(mean(ImYUV(:,:,capa)))],2,2);

        % MPE no lineal
        [MSE,MPEnln(capa),dx,MPEx,MPEoo,MPEexpesp] = disdis7(double(ImYUV(:,:,capa)),ImRYUV(:,:,capa),[3 mean(mean(ImYUV(:,:,capa)))],2,1,2,2);

        % MPE no lineal JMLR
        [MSE,MPEnlJMLRn(capa),dx,MPEx,MPEoo,MPEexpesp] = disdis7(double(ImYUV(:,:,capa)),ImRYUV(:,:,capa),[3 mean(mean(ImYUV(:,:,capa)))],1,0.5,2,2);

    else

        % MPE lineal
        [MSE,MPEln(capa),dx0,MPEx0,MPEoo0,MPEexpesp0] = disdis_lineal(Im,ImR,2,[3 mean(mean(Im))],2,2);

        % MPE no lineal
        [MSE,MPEnln(capa),dx,MPEx,MPEoo,MPEexpesp] = disdis7(Im,ImR,[3 mean(mean(Im))],2,1,2,2);

        % MPE no lineal JMLR
        [MSE,MPEnlJMLRn(capa),dx,MPEx,MPEoo,MPEexpesp] = disdis7(Im,ImR,[3 mean(mean(Im))],1,0.5,2,2);
        
    end
end

% Valores promedios
for i = 1:N
    
%     % RMSE
%     RMSE = RMSE + pesos(i) * RMSEn(i);

    % SSIM
    SSIM = SSIM + pesos(i) * SSIMn(i);

    % MPE lineal
    MPEl = MPEl + pesos(i) * MPEln(i);

    % MPE no lineal
    MPEnl = MPEnl + pesos(i) * MPEnln(i);

    % MPE no lineal JMLR
    MPEnlJMLR = MPEnlJMLR + pesos(i) * MPEnlJMLRn(i);

end

RMSE = sqrt( sum((Im(:) - ImR(:)) .^ 2) / numel(Im) );