function [H,kk1,kk2,gamm]=constantes_respY(gamm,cero,tipo_alfa);

% CONSTANTES_RESPY devuelve las constantes de la normalizacion divisiva de
% la DCT:
%
%      alfa  = filtro de tipo CSF
%      beta  = control de la saturacion
%      gamma = exponente aplicado a la DCT
%      h     = kernel de la normalizacion divisiva
%
% Se asume que fs=64 cl/grad y que el tamao de la DCT es 16*16
%
% Existen dos opciones generales para los parametros:
%
%     * gamma = 2      (respue3)
%     * gamma = 0.98   (respue4)
%
% Ademas puede elegirse el tipo de CSF:
%
%     * tipo_alfa = 1  CSF del ajuste
%     * tipo_alfa = 2  CSF de Ngan (escalada como la del ajuste)
%     * tipo_alfa = 3  CSF de Kelly (escalada como la del ajuste)
%
% Y puede anularse o no la diagonal del kernel.
%
% USO: [H,kk1,kk2,gamm]=constantes_resp(gamm,cero,tipo_alfa);

fs=64;
lcuan=16;

if gamm==2

%%%%%%%% Constantes Respue3

   CSFngan=[0.2320    0.8245    1.0000    0.9150    0.7311    0.5402    0.3795    0.2574    0.1701  0.1102    0.0703    0.0443    0.0276    0.0170    0.0104    0.0064];
   CSFkelly=[0.0040    0.7284    1.0000    0.7723    0.4712    0.2527    0.1249    0.0583    0.0262 0.0114    0.0048    0.0040    0.0040    0.0040    0.0040    0.0040];
   kk1 =[0.0305    0.1717    0.3160    0.2855    0.1735    0.1333    0.1211    0.1159    0.1021    0.0837    0.0636    0.0461    0.0330    0.0300  0.0301    0.0302];

   if tipo_alfa==2
      kk1=CSFngan*max(kk1);         
   elseif tipo_alfa==3
      kk1=CSFkelly*max(kk1);       
   end    
   
   kk2 =[0.0109    0.0028    0.0022    0.0024    0.0034    0.0048    0.0064    0.0084    0.0094    0.0099    0.0102    0.0104    0.0106    0.01065 0.01073   0.01079];
   gamm=2;
   fact=0.6;

%%%%%%%% Constantes Respue4
else

   CSFngan=[0.2320    0.8245    1.0000    0.9150    0.7311    0.5402    0.3795    0.2574    0.1701  0.1102    0.0703    0.0443    0.0276    0.0170    0.0104    0.0064];
   CSFkelly=[0.0040    0.7284    1.0000    0.7723    0.4712    0.2527    0.1249    0.0583    0.0262 0.0114    0.0048    0.0040    0.0040    0.0040    0.0040    0.0040];
   kk1 = [0.0034    0.0194    0.0351    0.0316    0.0197    0.0151    0.0138    0.0131    0.0116    0.0092  0.0069    0.0050    0.0035    0.0032    0.0032    0.0032];

   if tipo_alfa==2
      kk1=CSFngan*max(kk1);         
   elseif tipo_alfa==3
      kk1=CSFkelly*max(kk1);       
   end    
   
   kk2 = [0.0149    0.0040    0.0032    0.0034    0.0048    0.0066    0.0090    0.0117    0.0131    0.0131  0.0131    0.0131    0.0131    0.0131    0.0131    0.0131];
   gamm=0.9799;
   fact=0.5;
end
   
%%%%%%%% Kernel   
   
   fx=linspace(0,fs/2-fs/(2*lcuan),lcuan);
   
   Fx=ones(lcuan,1)*fx;
   Fy=Fx';
   F=sqrt(Fx.^2+Fy.^2);
    
   % Reordenacion 1D del dominio
   
   fx=zigzag(Fx);
   fy=zigzag(Fy);
   f=zigzag(F); 
   
   % Calculo del kernel de interaccion (que se aplicara sobre la ordenacion 1D de la seal).

   H=zeros(lcuan^2,lcuan^2);
   for i=1:lcuan^2
       s=fact*(1/3*f(i)+0.1);
       hh=exp(-((Fx-fx(i)).^2+(Fy-fy(i)).^2)/s.^2);
       if cero==1
          if i==1
             hh=zeros(lcuan,lcuan);
             hh(1,2)=0.333;
             hh(2,2)=0.333;
             hh(2,1)=0.333;
          else
             c1=Fx==fx(i);
             c2=Fy==fy(i);
             c=(c1.*c2)==0;
             hh=hh.*c;
          end
       end
       if i~=1
          hh(1,1)=0;
       end    
       hh=hh/sum(sum(hh));
       H(i,:)=(zigzag(hh))';
   end