function [MSE,d,dx,MPEx,MPEoo,MPEexpesp]=disdis7(im1,im2,norm,exponente,fact_mask,expfrec,expesp);
 
% DISDIS7 aplica la medida de distancia perceptual 
%
%    dx(rx,rx+Drx) = ( (abs(Drx').^(expfrec/2)) * (abs(Drx).^(expfrec/2)) )^(1/expfrec)
%
% a las respuestas, rx(Ax), de cada subbloque, Ax, de las imagenes, im, im+Dim ,que se le pasan.
% (bloques de 16*16 asumiendo fs=64 cpd. SORRY de momento solo aplicable a matrices 
%  cuadradas de lado potencia de 2)
%
% Se diferencia de disdis6 en que:
% (1) es posible utilizar tanto los parametros
%     de naka8 (exponente 2) y de naka100 (exponente 0.98)
%
%     exponente = 2  ->  naka8
%     exponente = 1  ->  naka100
%
% (2) es posible aplicar un factor a beta para incrementar el efecto del
% enmascaramiento:
%
%     fact_mask = 1  Aplica la normalizacion tal cual
%     fact_mask < 1  se reduce beta aumentando el efecto del masking
%                    (disdis6 aplica fact_mask=0.5 sobre el beta de naka100)
%     fact_mask > 1  se incrementa beta reduciendose el efecto del masking
%
% Utiliza bock-DCT como dominio frecuencial local previo a la
% normalizacion. No se usan interacciones espaciales entre bloques...
%
% Despues estas diferencias locales 'por-bloque', dx, se suman espacialmente
% utilizando una norma de exponente expesp:
%
%                         /                \ ^ (1/expesp)
%       d(im,im+Dim) =   |  sum dx^(expesp) |
%                         \  x             /
%
% Notese que si los exponentes de sumacion (las normas) frecuencial y espacial se toman
% como expfrec = expesp = 2 se esta en condiciones de aplicar la geometria
% riemaniana, y estariamos en el caso guay (se puede calcular W en cualquier otro lado). 
% El caso guay es:
% 
%                      /                \ ^ (1/2)
%       d(r,r + Dr) = | Dr' * W(r) * Dr  |  
%                      \                /
%
% con metrica W(r) = I. Especifically,
%
%                      /                                           \ ^ (1/2)
%       d(r,r + Dr) = |     sum       Drxf * Wxx'ff'(r) * Drx'f'   |  
%                      \  x x' f f'                                /
%
% con Wxx'ff' = 1 para todo x \neq x', f \neq f' 
% 
% Algunos modelos empiricos, no obstante dicen otra cosa
% (expesp=3,expfrec=4)... Bueno, pero al menos Heeger dice que expfrec=2...
%
% Ademas de esta distancia, d, se da el conjunto de distancias, dx para ver
% un mapita local (espacial).
%
% Ademas saca un mapa con el Maximo Error Perceptual para cada bloque 
% (norma frecuencial infinita):
%
%    MPEx = max( abs(Drxf) )    (Recordemos que en el dominio normaliz Wxx'ff' = delta_xx'ff') 
%
%  y da un MPE promedio utilizando dos sumaciones:
%
%  - Norma espacial infinita:
%
%     MPEoo  = max( MPEx )    
%
%  - Norma espacial expesp:
%
%                      /                  \ ^ (1/expesp)
%       MPEexpesp =   |  sum MPEx^(expesp) |
%                      \  x               /
%
% Y ademas, despues de tanto coazo, saca el MSE por si las moscas...
%
%
% USO: [MSE,d,dx,MPEx,MPEoo,MPEexpesp]=disdis7(im1,im2,[norm parametro],exponente_norm,fact_mask,expfrec,expesp);
% 
% Para el tipo de normalizacion de contraste [norm parametro] ver CONTRAST


   tam=size(im1);
   tam=tam(1);
   
   %lcuan=tam/(2^Ncuan);
   
   lcuan=16;
   Ncuan=log(tam/lcuan)/log(2);
   lados=[tam tam];
   imq=zeros(tam,tam);
   dctq=zeros(tam,tam);
   codq=zeros(tam,tam);
   
   
   
   posai=[tam tam]/2-round(tam/2);
   posbd=[tam tam]/2+round(tam/2);
   coorcuanai=floor([(posai(1)-1)/lcuan+1 (posai(2)-1)/lcuan+1]);
   coorcuanbd=floor([(posbd(1)-1)/lcuan+1 (posbd(2)-1)/lcuan+1]);
   if coorcuanai(1)<1
        coorcuanai(1)=1;
   end 
   if coorcuanai(2)<1
        coorcuanai(2)=1;
   end 
   if coorcuanbd(1)>(2^Ncuan)
        coorcuanbd(1)=2^Ncuan;
   end     
   if coorcuanai(2)>(2^Ncuan)
        coorcuanbd(2)=2^Ncuan;

   end 

    
%%%%%%%%%%%%%%%%%%%%%%% 'CALCULO' DE LAS CONSTANTES   
   
   fs=64;
   cero=0;
   [H,kk1,kk2,gamm]=constantes_resp(exponente,cero);
   
  
%    % Cosntantes de Naka8 (ajustado con anchuras fac=0.6)
%    %kk1 =[0.0305    0.1717    0.3160    0.2855    0.1735    0.1333    0.1211    0.1159    0.1021    0.0837    0.0636    0.0461    0.0330    0.0300  0.0301    0.0302];
%    %kk2 =[0.0109    0.0028    0.0022    0.0024    0.0034    0.0048    0.0064    0.0084    0.0094    0.0099    0.0102    0.0104    0.0106    0.01065 0.01073   0.01079];
%    %gamm=2;
%    %fact=0.6;
%    
% %    % Cosntantes de Naka100 (ajustado con anchuras fac=0.5)
% %    kk1 = [0.0034    0.0194    0.0351    0.0316    0.0197    0.0151    0.0138    0.0131    0.0116    0.0092  0.0069    0.0050    0.0035    0.0032    0.0032    0.0032];
% %    kk2 = [0.0149    0.0040    0.0032    0.0034    0.0048    0.0066    0.0090    0.0117    0.0131    0.0131  0.0131    0.0131    0.0131    0.0131    0.0131    0.0131];
% %    gamm=0.9799;
% %    fact=0.5;
% 
%    % Cosntantes de Naka100 (reduciendo kk2 para aumentar el efcto de masking)
%    kk1 = [0.0034    0.0194    0.0351    0.0316    0.0197    0.0151    0.0138    0.0131    0.0116    0.0092  0.0069    0.0050    0.0035    0.0032    0.0032    0.0032];
%    kk2 = 0.5*[0.0149    0.0040    0.0032    0.0034    0.0048    0.0066    0.0090    0.0117    0.0131    0.0131  0.0131    0.0131    0.0131    0.0131    0.0131    0.0131];
%    gamm=0.9799;
%    fact=0.5;
% 
%    
% %    % Constantes de Naka100 cambiando kk1 por la CSF (escalada para tener la misma energia que 
% %    % kk1) para asi dar mas peso a las frecuencias medias a ver si (al
% %    % menos) sale el ejemplito de ejemplo_metrica_imagen3.m...
% %    kk1 = [0.0034    0.0194    0.0351    0.0316    0.0197    0.0151    0.0138    0.0131    0.0116    0.0092  0.0069    0.0050    0.0035    0.0032    0.0032    0.0032];
% %    kk2 = [0.0149    0.0040    0.0032    0.0034    0.0048    0.0066    0.0090    0.0117    0.0131    0.0131  0.0131    0.0131    0.0131    0.0131    0.0131    0.0131];
% %    [csf,logciaf]=ngan(32,16);
% %    kk1 = sqrt(sum(kk1.^2))*csf/sqrt(sum(csf.^2));
% %    gamm=0.9799;
% %    fact=0.5;
   
%    % Dominio de frecuencias de la DCT2D
%    
%    fx=linspace(0,fs/2-fs/(2*lcuan),lcuan);
%    
%    Fx=ones(lcuan,1)*fx;
%    Fy=Fx';
%    F=sqrt(Fx.^2+Fy.^2);
%     
%    % Reordenacion 1D del dominio
%    
%    fx=zigzag(Fx);
%    fy=zigzag(Fy);
%    f=zigzag(F); 
   
% Calculo del kernel de interaccion (que se aplicara sobre la ordenacion 1D de la seal).

   % Sin tener cuidado de la interaccion con la continua (Juan tuvo problemas,
   % pero creo que yo no, porque yo siempre he tenido la precaucion de
   % meterle un cero a la continua dentro de los programitas de calculo de
   % la respuesta

%    cero=0;
%    H=zeros(lcuan^2,lcuan^2);
%    for i=1:lcuan^2
%        s=fact*(1/3*f(i)+0.1);
%        hh=exp(-((Fx-fx(i)).^2+(Fy-fy(i)).^2)/s.^2);
%        if cero==1
%           if i==1
%              hh=zeros(lcuan,lcuan);
%              hh(1,2)=0.333;
%              hh(2,2)=0.333;
%              hh(2,1)=0.333;
%           else
%              c1=Fx==fx(i);
%              c2=Fy==fy(i);
%              c=(c1.*c2)==0;
%              hh=hh.*c;
%           end
%        end
%        hh=hh/sum(sum(hh));
%        H(i,:)=(zigzag(hh))';
%    end

%    cero=0;
%    H=zeros(lcuan^2,lcuan^2);
%    for i=1:lcuan^2
%        s=fact*(1/3*f(i)+0.1);
%        hh=exp(-((Fx-fx(i)).^2+(Fy-fy(i)).^2)/s.^2);
%        if cero==1
%           if i==1
%              hh=zeros(lcuan,lcuan);
%              hh(1,2)=0.333;
%              hh(2,2)=0.333;
%              hh(2,1)=0.333;
%           else
%              c1=Fx==fx(i);
%              c2=Fy==fy(i);
%              c=(c1.*c2)==0;
%              hh=hh.*c;
%           end
%        end
%        if i~=1
%           hh(1,1)=0;
%        end    
%        hh=hh/sum(sum(hh));
%        H(i,:)=(zigzag(hh))';
%    end

%%%%%%%%%%%%%%%%%%%%   
   
% DCTs y paso a contrastes   

   dcti1=dct2r(im1,Ncuan); 
   [a1,Lm1]=contras2(dcti1,Ncuan,norm);
   DC1=Lm1*16;
   
   dcti2=dct2r(im2,Ncuan); 
   [a2,Lm2]=contras2(dcti2,Ncuan,norm);
   DC2=Lm2*16;
   

%
   
% d
% dx
% MPEx
% MPEoo
% MPEexpesp

dx=zeros(coorcuanbd(1),coorcuanbd(2));
MPEx=dx;

fprintf('Computing MPE distortion measure using a non-linear response model\n');

   for ii=coorcuanai(1):coorcuanbd(1)
       fprintf('.');
       for jj=coorcuanai(2):coorcuanbd(2)
           iii=(ii-1)*lcuan+ceil(lcuan/2);
           jjj=(jj-1)*lcuan+ceil(lcuan/2); 
           blo1=sacasub(a1,[iii jjj],[lcuan lcuan],0);
           blo2=sacasub(a2,[iii jjj],[lcuan lcuan],0);
           
           %[h,h_a,r,grad,alfa,beta]=respue4(aa,kk1,kk2,gamm,0.5,64,cero);
           
           [IN,R1,GR,alfa,beta]=respue5(blo1,kk1,fact_mask*kk2,gamm,H,0);
           [IN,R2,GR,alfa,beta]=respue5(blo2,kk1,fact_mask*kk2,gamm,H,0);
           
           Drf=abs(R1-R2);
           
           dx(ii,jj)= sum(sum((Drf.^(expfrec/2)).*(Drf.^(expfrec/2)))).^(1/expfrec);
           MPEx(ii,jj)=max(max(Drf));
           
       end
   end

fprintf('\n');

d=(sum(sum(dx.^(expesp))))^(1/expesp);

MPEexpesp=(sum(sum(MPEx.^(expesp))))^(1/expesp);
MPEoo=max(max(MPEx));

MSE = sum(sum( (im1-im2).^2 ))/(tam^2);
