function [RMSE,SSIM,SCIELab,MPE] = distorsiones_color(Im,ImR,datos,exp_sum)

% Calcula el RMSE, el SSIM, el S-CIELab y el MPE entre dos imagenes en RGB
%
% Im      -> Imagen original (RGB)
% ImR     -> Imagen distorsionada (RGB)
% exp_sum -> Exponente de sumacion para el SCIELab. Si no se especifica, se
%            pondra su valor a 1 por defecto
% datos   -> Estructura de datos necesaria para usar jpeg2000_encoder.m
%
% USO: [RMSE,SSIM,SCIELab,MPE] = distorsiones_color(Im,ImR,exp_sum,datos)


if(nargin < 4)
    exp_sum = 1;    
end

% Dimensiones de la imagen
[Nf,Nc,N] = size(Im);

% Calculo de distorsiones
SSIMn = zeros(N,1);

% Trabajaremos con las imagenes como uint8
Im = uint8(Im);
ImR = uint8(ImR);

% % Transformacion cromatica YUV
% ImYUV = my_rgb2yuv(Im);
% ImRYUV = my_rgb2yuv(ImR);


% SSIM - Calculado en el espacio RGB
for capa = 1:N

    SSIMn(capa) = ssim_index(Im(:,:,capa),ImR(:,:,capa));

end

SSIM = SSIMn;
% SSIM = mean(SSIMn');

% RMSE - Calculado en el espacio RGB
if(N == 3)
    RMSE = sqrt(sum(sum(sum((Im-ImR).^2))) / (3*Nf*Nc));
else
    RMSE = sqrt(sum((Im-ImR).^2) / (Nf*Nc));
end

% S-CIE L*a*b*
if((nargout > 2) && (N == 3))

    SCIELab = calculo_scielab(Im,ImR,exp_sum);

end

% MPE - Distancias perceptuales en el dominio de la respuesta no lineal
if(nargout > 3)
    MPE = distancia_dominio_r(Im,ImR,datos);
end