function [IN,R,GR,alfa,beta]=respue5(dctinic,k1,k2,gamm,H,calc_grad)
   
% 
% RESPUE5 calcula la respuesta (y el gradiente) a una DCT2D local
% (expresada en contraste) considerando interacciones entre los coeficientes,
% simulando la respuesta de los detectores de frecuencia del SVH.
% 
%   DCTn(f) = (k1(f) DCT(f))^g / ( k2(f) + [H*(k1(f) DCT(f))^g](f) ) 
% 
% A esta funcion se han de pasar los parametros de la normalizacion 
% H, k1, k2 (solo la depend. en frecuencia) y  g, 
% (Es decir, tal como los da naka100.m) 
%
% Devuelve:
% 
%  La interaccion, interac=H*abs(a)^g
%  La respuesta, Resp
%  El jacobiano de la respuesta, Grad  (puede optarse por no calcularlo)
%     si se decide no calcular el jacobiano, el programa fija GR=0
%  Los parametros k1 y k2 en forma de matriz, kk1, kk2
%
% NOTA: Se supone que el bloque que se mete en la funcion ya esta expresado en
%       contrastes (ver CONTRAST)
%
% USO:
% 
% [interac,Resp,Grad,kk1,kk2]=respue5(dctinic,k1,k2,gamm,H,calc_grad)
% 
  
% Tamanyo de la entrada (esto es una chorrada porque todo debe casar con H... supongo 16*16)
      
   tam=size(dctinic);
   tam=tam(1);
   lados=[tam tam];
   
% Lado de los subbloques locales
     
   lcuan=lados(1);
 
% Paso a 2D y posterior reordenacion 1D de las constantes que provienen de NAKA100.M
    
   k1=simrev(k1);
   k1=zigzag(k1);   
   k2=simrev(k2);
   k2=zigzag(k2); 
   
   alfa=k1;
   beta=k2;
   
%%%%%%%%%%%%%%%%%%%%%%%%%%
          
              cub=dctinic;
              
           % Ordenacion 1D del bloque
              
              cub=zigzag(cub);
              
           % Desplazamiento del origen para evitar singularidades
              
              cub=abs(cub);
                            
           % Rectificacion
              
              cucu=(k1.*cub).^gamm;
              
           % Convolucion del kernel por la seal rectificada
              
              interacc=H*[0;cucu(2:length(cucu))];      
              
           % Respuesta
              
              R=cucu./(k2+interacc);
              R(1)=sqrt(cub(1));
              
           % Gradiente
           
              if calc_grad==1
              
              I=eye(lcuan^2);
              GR=zeros(lcuan^2,lcuan^2);            
              GR(1,1)=1;     
              
              for i=2:lcuan^2,
                  for j=2:lcuan^2,
                      % GR(i,j)= 2*(abs(sqrt(cucu(i)))/(k2(i)+interacc(i))*I(i,j)-(cucu(i)*abs(sqrt(cucu(j)))/((k2(i)+interacc(i))^2))*H(i,j));
                      GR(i,j)= gamm*(abs(  (cucu(i).^(1/gamm)).^(gamm-1)  )/(k2(i)+interacc(i))*I(i,j)-(cucu(i)*abs( ((cucu(j)).^(1/gamm)).^(gamm-1) )/((k2(i)+interacc(i))^2))*H(i,j));
                  end
              end
              
              else
              GR=0;    
              end    

           % Reordenacion 2D de la respuesta, de la interaccion y de la seal retransformada.

              R=dezigzag(R);
              IN=dezigzag(interacc);
