function [x]=coord(pos,N)

% Los elementos de una matriz N1*N2*....*Nd (d-dimensional) pueden
% ordenarse en fila en un vector 1*(N1*N2*....*Nd).
% 
% La ordenacion mas habitual es la ordenacion en la que los indices
% varian mas rapido cuanto mas a la derecha estan (Notacion matricial
% normal). Por ejemplo:
%
%               ()--()--()
%              /   /   / |
%             ()--()--()()
%            /   /   / |/|
%           ()--()--()()()
%            |   |   |/|/
%           ()--()--()() 
%            |   |   |/
%           ()--()--()
%
%
%        POSICION          ELEMENTO
%
%            1               1 1 1
%            2               1 1 2
%            .                 .
%            .                 .
%            .                 .
%            N3              1 1 N3
%            
%            N3+1            1 2 1
%            N3+2            1 2 2
%             .                .
%             .                .    
%             .                . 
%            2*N3            1 2 N3
%                                       
%            2*N3+1          1 3 1                           
%             .                .
%             .                .
%             .                .     
%             .                .
%            N2*N3           1 N2 N3                             
%             .                .
%             .                .  
%'COORD' da cuales son las coordenadas (segun esta ordenacion) 
% del elemento situado en la posicion p 
%    
% USO: coord=coord(p,[N1....Nd]); 
% 
% Si la posicion es imposible devuelve zeros(1,D)

NN=prod(N);

if ((pos>0)&(pos<NN+1))
   D=length(N);
   p=fliplr(cumprod(fliplr(N(2:D))));

   x(1)=ceil(pos/prod(N(2:D)));

   for j=2:D-1
       pe=p(1:j-1);
       x(j)=ceil((pos-(x-1)*pe')/(prod(N(j+1:D))));    
   end    

   pe=p(1:D-1);
   x(D)=ceil((pos-(x-1)*p'));
else
   coord=zeros(1,D);
end





