function [p]=posicion(coordd,N)

% Los elementos de una matriz N1*N2*....*Nd (d-dimensional) pueden
% ordenarse en fila en un vector 1*(N1*N2*....*Nd).
% 
% La ordenacion mas habitual es la ordenacion en la que los indices
% varian mas rapido cuanto mas a la derecha estan (Notacion matricial
% normal). Por ejemplo:
%
%        POSICION          ELEMENTO
%
%            1               1 1 1
%            2               1 1 2
%            .                 .
%            .                 .
%            .                 .
%            N3              1 1 N3
%            
%            N3+1            1 2 1
%            N3+2            1 2 2
%             .                .
%             .                .    
%             .                . 
%            2*N3            1 2 N3
%                                       
%            2*N3+1          1 3 1                           
%             .                .
%             .                .
%             .                .     
%             .                .
%            N2*N3           1 N2 N3                             
%             .                .
%             .                .  
%'POSICION' da cual es la posicion (segun esta ordenacion) 
% del punto definido por las coordenadas (x1,x2,....,xd),donde
% cada xi puede tomar cualquier valor xi = 1......Ni.
% Si  algun elemento del vector de coordenadas xi>Ni devuelve 
% un cero. 
%   
% USO: posic=posicion([x1....xd],[N1....Nd]); 
%

D=length(coordd);

a=double(  ((N-coordd)>=0)>0  );
if (prod(a)&(prod(coordd)>0)) 
    pr=fliplr(cumprod(fliplr(N(2:D))));
    ult=coordd(D);
    coordd=coordd(1:D-1);
    p=(coordd-1)*pr'+ult;
else
    p=0;
end
