function [c,banda]=coor_w_pyr(p,ind)

% COOR_W_PYR da las coordenadas ([escala orient fila col]) del coeficiente wavelet solicitado
% 
% Se asume la ordenacion de los coeficientes que se usa en matlabpyrtools,
% es decir, ordenacion de escalas de fina a grosera, ordenacion de orientaciones 
% horizontal, vertical y diagonal, ordenacion de las posiciones por
% columnas (como en reshape, no como en raster!).
%
% Por tanto:
%
%   - La escala va desde 1 (la mas fina) hasta k (la mas grosera)
%   - La orientacion puede valer: 1 (horizontal), 2 (vertical) o 3 (diagonal)
%   - La posicion (filas o columnas) puede ir desde 1 hasta N/(2^escala)
%
% (Para una imagen N*N) la posicion de los coeficientes wavelet, que estan en 
% el vector PYR, va desde 1 hasta N^2 
%
% [coordenadas,banda]=coor_w_pyr(p,ind)

s=size(ind);
%num_escalas=(s(1)-1)/3;

banda=1;
for i=1:s(1)
    indices = pyrBandIndices(ind,i);
    pp=find((indices-p)==0); 
    if isempty(pp)
       banda=banda+1; 
    else
       break
    end    
end

escala = floor(banda/3)+(abs((banda/3)-floor(banda/3))>0);
orient = 3 - (3*escala - banda);
co = coord(pp,ind(banda,:));

c = [escala orient co(2) co(1)];