function alfas = generacion_alfas_v2(Aos,sigmas_hv,sigmas_d,expon,escalas)

% Genera los perfiles CSF de acuerdo con la funcion descrita en 'Rango de
% valores.pdf'
%
% Aos       -> Amplitud para los canales Y y UV                 [20  -  80]
% sigmas_hv -> Controla la anchura de la gaussiana en las orientaciones
%              horizontal(1) y vertical (2). Canales Y y UV     [1.5 - 3.5]
% sigmas_d  -> Controla la anchura de la gaussiana en la orientacion
%              diagonal(3). Canales Y y UV                      [1.5 - 3.5]
% expon     -> Exponente para controlar la forma de la funcion  [1.5 -  10]
% escalas   -> Numero de escalas utilizadas en la transformada Wavelet  [4]
%
% Uso: alfas = generacion_alfas_v2([Ao_y Ao_uv],[sigma_hv_y sigma_hv_uv],[sigma_d_y sigma_d_uv],expon,escalas)
%
% Siendo cada una de las dimensiones de 'alfas':
%
% alfas(escala,orientacion,canal cromatico)


alfas = zeros(escalas,3,3);

for capa = 1:3

    if(capa == 1)
        Ao = Aos(1);
        sigmas = [sigmas_hv(1) sigmas_d(1)];
    else
        Ao = Aos(2);
        sigmas = [sigmas_hv(2) sigmas_d(2)];
    end
    
    for escala = 1:escalas % HF --- LF        

        for orientacion = 1:3 % H V D

            if(orientacion == 3)
                sigma = sigmas(2);
            else
                sigma = sigmas(1);
            end
            
            alfa_i = Ao .* exp( - ( (escalas - escala) / sigma ) ^ expon );           

            alfas(escala,orientacion,capa) = alfa_i;

        end

    end
    
end