function a_rec = inv_normal_div(r,g,beta,h,iteraciones)

% Invierte el proceso de la Normalizacion Divisiva mediante expansion en
% series:
%
% abs( a ) .^ g = DB * r + en
% en = ( Dr * h ) * ( en-1 + DB * r )
%
% Donde 'a' es el vector wavelet, 'g' el exponente de la no linealidad de
% la normalizacion divisiva, DB una matriz cuadrada con su diagonal igual a
% 'beta', 'r' es el vector de la respuesta de la normalizacion divisiva y
% 'Dr', al igual que 'DB', es otra matriz cuadrada cuya diagonal contiene
% los elementos de 'r'.
%
% r           -> Respuesta de la Normalizacion Divisiva
% g           -> Exponente de la no linealidad de la Normalizacion Divisiva
% beta        -> Factor para evitar que la respuesta valga infinito
% h           -> Kernel utilizado en la Normalizacion Divisiva
% iteraciones -> Numero de iteraciones para aproximar mas o menos la serie


% Signos del vector wavelet
signos_a = sign(r);

% Trabajaremos con el valor absoluto de 'r'
r = abs(r);

% Matrices diagonales empleadas
Dr = spdiags(r,0,size(r,1),size(r,1));
DB = beta * speye(size(r,1),size(r,1));

% Primeros terminos de la serie
DBr_0 = DB * r;
DBr   = DBr_0;

Drh   = Dr * h;

% Proceso iterativo (expansion en series)
while(iteraciones ~= 0)

    DBr = DBr_0 + Drh * DBr;

    iteraciones = iteraciones - 1;

end

% Inversion de la no linealidad
a_rec = DBr .^ (1/g);

% Recuperacion del signo del vector wavelet
a_rec = abs(a_rec) .* signos_a;