function SCIELab = calculo_scielab(Im,ImR,exp_sum)

% Calcula el SCIELab como la media de la matriz de errores perceptuales
% incrE.
%
% A partir de dos imagenes RGB (original y distorsionada), las convierte en
% formato XYZ, aplica un filtrado espacial y las convierte al espacio
% L*a*b*.
%
% Los errores se calculan como:
%
% incrE = sqrt( incrL ^ 2 + incra ^ 2 + incrb ^ 2 )
%
% Im      -> Imagen original (RGB)
% ImR     -> Imagen distorsionada (RGB)
% exp_sum -> Exponentes de sumacion para obtener el resultado

if(nargin < 3)
    exp_sum = 1;
end

% Dimensiones de la imagen
filas = size(Im,1);
columnas = size(Im,2);

% Convertimos las imagenes en formato 'double' y las ponemos en un rango
% entre 0 y 1.
Im = double(Im);
ImR = double(ImR);

Im = Im .* ((Im >= 0) & (Im <= 255)) + 0 .* (Im < 0) + 255 .* (Im > 255);
ImR = ImR .* ((ImR >= 0) & (ImR <= 255)) + 0 .* (ImR < 0) + 255 .* (ImR > 255);

Im = Im ./ 255;
ImR = ImR ./ 255;

% Variables necesarias: frecuencia de muestreo, transformacion RGB a XYZ
% Coordenadas del blanco en XYZ.
sampPerDeg = 64; %23
load displaySPD
load SmithPokornyCones
rgb2lms = cones'* displaySPD;
load displayGamma
rgbWhite = [1 1 1];
whitepoint = rgbWhite * rgb2lms';
imageformat = 'lms';

% RGB a XYZ
Imrgb  = [Im(:,:,1) Im(:,:,2) Im(:,:,3)];
ImRrgb = [ImR(:,:,1) ImR(:,:,2) ImR(:,:,3)];

Imxyz  = changeColorSpace(Imrgb,rgb2lms);
ImRxyz = changeColorSpace(ImRrgb,rgb2lms);

% Obtenemos los errores
errorImage = scielab(sampPerDeg, Imxyz, ImRxyz, whitepoint, imageformat);

% Medida del error como la media aritmetica
SCIELab = [];

for i = 1:length(exp_sum)
    
    SCIELab = [SCIELab (sum(sum(errorImage.^exp_sum(i)))./(filas * columnas))^(1/exp_sum(i))];
    
end